==> haskell-hasql-pool-0.4.1-72-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.1
id: hasql-pool-0.4.1-AQ2EG8ZtO1j4JX7vq7SIZA
key: hasql-pool-0.4.1-AQ2EG8ZtO1j4JX7vq7SIZA
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 444fcb2480ae360d2b7465fd05ccf57f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hasql-pool-0.4.1
hs-libraries: HShasql-pool-0.4.1-AQ2EG8ZtO1j4JX7vq7SIZA
depends:
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    hasql-0.19.18.1-9XVNrzYoCDE9Ghqv8uibdc time-1.8.0.2
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
abi-depends: resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=5b077650442ac89e21628081801bbe25
             hasql-0.19.18.1-9XVNrzYoCDE9Ghqv8uibdc=77ccb39dfcbca2e163b80d22101f1113
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.4.1-74-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.1
id: hasql-pool-0.4.1-GZobrh5IqYdALgcihvoZXt
key: hasql-pool-0.4.1-GZobrh5IqYdALgcihvoZXt
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 74580d99dde95d807f545f48ff697e4d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hasql-pool-0.4.1
hs-libraries: HShasql-pool-0.4.1-GZobrh5IqYdALgcihvoZXt
depends:
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    hasql-0.19.18.2-6LYEIdON78xLusUPFM5Kjr time-1.8.0.2
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
abi-depends: resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=5b077650442ac89e21628081801bbe25
             hasql-0.19.18.2-6LYEIdON78xLusUPFM5Kjr=4ce3d0969de0ce8c0faf5614e280115c
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
